Welcome to FastMBAR! — FastMBAR 1.0-rc documentation

Skip to main content
`Ctrl`+`K`

# Welcome to FastMBAR!

## What is FastMBAR?

FastMBAR is a Python solver for large scale MBAR/UWHAM equations. It can calculate relative free energies of a large number of thermodynamic states. It is useful for both alchemical free energy calculations and calculating potential of mean force (PMF) in umbrella sampling and temperature/Hamiltonian replica exchange simulations.

## Why FastMBAR?

FastMBAR can use both CPUs and GPUs. It is extramely fast for solving large scale MBAR/WHAM equations when it uses GPUs. Moreover, it is not limited by the memory size of a GPU. Therefore, you will find it especially useful when you want to calculate relative free energies for a large number of states, such as calculating multiple dimensional PMF with umbrella sampling and calculating free energies for a large number of states in alchemical free energy approaches.

## How to use FastMBAR?

It just takes a few lines of commands to install and use FastMBAR.

- Installation
  - 1. New to Python or Anaconda?
  - 2. Install FastMBAR with pip
  - 3. Test the Installation of FastMBAR
- Usage
  - 1. When to use MBAR equations?
  - 2. How to use FastMBAR?
- FastMBAR API
- Examples
  - Install Extra Required Python Packges
  - Examples
- References